@@ -32,8 +32,12 @@ def version():
         - BaseListView的retrieve修复queryset中annotate字段失效问题
         - 修复get_base_serializer在queryset进行values后annotate字段失效问题
         - 修复get_key_from_query_dc_or_self当query_dc中有False时返回值出错的bug
+        - 修复get_key_from_query_dc_or_self当query_dc中获取bool错误问题       # 2.4.1
+        - get_MySubQuery增加注释
+        - order_qs_ls_by_id完善为不限制长度
+        - zip功能完善       # 2.4.2
     """
-    v = "2.4.0"
+    v = "2.4.2"
     return v
 
 
