@@ -562,12 +562,7 @@ class ExcelImportExportAdmin(ImportAdmin, ExportExcelMixin):
 
     - 不能与admin.ModelAdmin一起用!
     """
-
-    # actions = ['export_as_excel']
-    def __init__(self, *args, **kwargs):
-        if 'export_as_excel' not in self.actions:
-            self.actions.append('export_as_excel')
-        super().__init__(*args, **kwargs)
+    default_export_action = True        # 默认增加导出按钮
 
     def get_search_results(self, request, queryset, search_term):
         """
@@ -590,6 +585,14 @@ class ExcelImportExportAdmin(ImportAdmin, ExportExcelMixin):
             ret = (queryset, False)
         return ret
 
+    def get_actions(self, request):
+        ACTION_NAME = 'export_as_excel'
+        if self.default_export_action and ACTION_NAME not in self.actions:
+            if self.actions is None:
+                self.actions = []
+            self.actions.append(ACTION_NAME)
+        ret = super().get_actions(request)
+        return ret
 
 class ListDisplayAdmin(ExcelImportExportAdmin):
     """
