@@ -380,16 +380,19 @@ def conv_queryset_to_dc_ls(queryset: QuerySet):
     return dc_ls
 
 
-def order_qs_ls_by_id(qs_ls, sort_by='id'):
-    df = pd.DataFrame(qs_ls).sort_values(by=sort_by)
+def order_qs_ls_by_id(qs_ls, sort_by='id', ascending=True):
+    df = pd.DataFrame(qs_ls)
+    if df.empty:
+        return []
+    df = df.sort_values(by=sort_by, ascending=ascending)
 
     cols = df.columns
     dc_ls = []
     for i, row in df.iterrows():
-        dc = {
-            cols[0]: row.get(cols[0]),
-            cols[1]: row.get(cols[1]),
-        }
+        dc = {}
+        for j in range(len(cols)):
+            _dc = {cols[j]: row.get(cols[j])}
+            dc.update(_dc)
         dc_ls.append(dc)
     return dc_ls
 
@@ -562,6 +565,15 @@ def get_MySubQuery(my_model, field_name, function_name, output_field=m.IntegerFi
     :param output_field: 使用Query计算后, 输出的字段类型
     :param alias: 计算后储存结果变量名, 默认为`tmp`
     :return: 子查询类`MySubQuery`
+
+    ## eg:
+    SQCount = get_MySubQuery(my_model=classification_qs_ls_0, field_name=foreign_key_name, function_name='Count', output_field=m.IntegerField)
+    classification_qs_ls = classification_qs_ls_0.annotate(
+        # 每个学科有多少种
+        count=SQCount(
+            classification_qs_ls_0.filter(**{key: m.OuterRef(key)})
+        ),
+    )
     """
     base_model = get_base_model(my_model)
     meta = base_model._meta
