@@ -158,15 +158,15 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         try:
             ret = self.retrieve(request)
         except Exception as e:
-            # 这里有坑, 因为有可能返回的是已经自定义好了的APIException, 例如权限不足错误.
-            if not isinstance(e, APIException):
-                # 没找到的情况, 404 Not Found
-                ret = None
-                status = 404
-                msg = str(e)
-                # msg = 'RetrieveError__' + str(e)
-            else:
-                raise e
+            # # 这里有坑, 因为有可能返回的是已经自定义好了的APIException, 例如权限不足错误.
+            # if not isinstance(e, APIException):
+            #     # 没找到的情况, 404 Not Found
+            #     ret = None
+            #     status = 404
+            #     msg = str(e)
+            #     my_api_assert_function(ret, msg, status)
+            # else:
+            raise e
 
         return ret, status, msg
 
@@ -174,11 +174,15 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         """retrieve时, object的获取"""
         retrieve_filter_field = self.retrieve_filter_field if self.retrieve_filter_field else 'id'
 
-        queryset = self.filter_queryset(self.get_queryset())
         pk = self.request.parser_context.get('kwargs').get('pk')
         dc = {retrieve_filter_field: pk}
-        queryset = queryset.filter(Q(**dc))
-        # print(get_executable_sql(queryset))
+        queryset = self.filter_queryset(self.get_queryset())
+        # queryset = queryset.filter(Q(**dc))
+        if isinstance(queryset, QuerySet):
+            queryset = queryset.filter(Q(**dc))
+        else:
+            queryset = queryset.objects.filter(Q(**dc))
+        print(get_executable_sql(queryset))
 
         if queryset.count() != 1:
             if queryset.count() > 1:
@@ -389,20 +393,23 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         """
 
         query_dc = self.get_request_data()
+        ret_0 = getattr(self, key) if hasattr(self, key) else None
 
         if get_type == 'list':
             data = get_list(query_dc, key)
         elif get_type == 'bool':
-            data = pure.convert_query_parameter_to_bool(query_dc.get(key))
-            if data is False:
-                return data
+            value = query_dc.get(key)
+            if value is not None:
+                data = pure.convert_query_parameter_to_bool(value)
+                if data is False:
+                    return data
+            else:
+                return ret_0
         else:
             data = query_dc.get(key)
 
         # 让request携带的数据可以覆盖自身的key值
-        ret_0 = getattr(self, key) if hasattr(self, key) else None
         ret_1 = data if data else None
-
         ret = ret_1 or ret_0
         return ret
 
@@ -464,11 +471,18 @@ class CompleteModelView(BaseListView, MyCreateModelMixin, MyUpdateModelMixin, My
     _post_type = None
     create_unique = True        # 创建时是否允许重复
 
-    def post(self, request, *args, **kwargs):
-        """增"""
-        post_type = request.data.get('post_type', 'create')
+    def get_post_type(self):
+        post_type = self.request.data.get('post_type', 'create')
         self._post_type = post_type
         my_api_assert_function(not post_type or post_type in self.post_type_ls, f"操作类型post_type指定错误! 取值范围: {self.post_type_ls}")
+        return post_type
+
+    def post(self, request, *args, **kwargs):
+        """增"""
+        post_type = self.get_post_type()
+        # post_type = request.data.get('post_type', 'create')
+        # self._post_type = post_type
+        # my_api_assert_function(not post_type or post_type in self.post_type_ls, f"操作类型post_type指定错误! 取值范围: {self.post_type_ls}")
 
         if post_type == 'create':
             return self.create(request, *args, **kwargs)
